summaryrefslogtreecommitdiffstats
path: root/kbabel/catalogmanager/catalogmanagerview.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60 (patch)
treebabc4a761925023e16fa94633959f35d1c251887 /kbabel/catalogmanager/catalogmanagerview.cpp
parent0813b39aed2cf4c84157a22c4c9594336d93d412 (diff)
downloadtdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.tar.gz
tdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kbabel/catalogmanager/catalogmanagerview.cpp')
-rw-r--r--kbabel/catalogmanager/catalogmanagerview.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/kbabel/catalogmanager/catalogmanagerview.cpp b/kbabel/catalogmanager/catalogmanagerview.cpp
index 63f2a077..3501f17b 100644
--- a/kbabel/catalogmanager/catalogmanagerview.cpp
+++ b/kbabel/catalogmanager/catalogmanagerview.cpp
@@ -98,8 +98,8 @@ const char* columnNames[] = {
#define COLTEXT(a) (i18n(columnNames[a]))
-CatalogManagerView::CatalogManagerView(KBabel::Project::Ptr project, TQWidget* tqparent,const char* name)
- : TQListView(tqparent,name)
+CatalogManagerView::CatalogManagerView(KBabel::Project::Ptr project, TQWidget* parent,const char* name)
+ : TQListView(parent,name)
, _dirWatch(0)
, _readInfoCount(0)
, _active(false)
@@ -1638,14 +1638,14 @@ void CatalogManagerView::slotFileCommand(int index)
if(index>=0 && item && item->isFile())
{
- CatManListItem* tqparent = (CatManListItem*)item->tqparent();
+ CatManListItem* parent = (CatManListItem*)item->parent();
TQString cmd=*(_settings.fileCommands).at(index);
cmd.replace("@PACKAGE@",item->name());
cmd.replace("@POFILE@",item->poFile());
cmd.replace("@POTFILE@",item->potFile());
- cmd.replace("@PODIR@",tqparent->poFile());
- cmd.replace("@POTDIR@",tqparent->potFile());
+ cmd.replace("@PODIR@",parent->poFile());
+ cmd.replace("@POTDIR@",parent->potFile());
cmd.replace("@POEMAIL@",item->text(COL_TRANSLATOR));
kdDebug(KBABEL_CATMAN) << cmd << endl;
@@ -1660,7 +1660,7 @@ void CatalogManagerView::slotFileCommand(int index)
connect( proc,TQT_SIGNAL( receivedStderr(KProcess*,char*,int) ), this
,TQT_SLOT( showOutput(KProcess*,char*,int) ) );
- *proc << "cd" << tqparent->poFile() << ";" << cmd;
+ *proc << "cd" << parent->poFile() << ";" << cmd;
proc->start(KProcess::NotifyOnExit,KProcess::AllOutput);
}
@@ -2206,7 +2206,7 @@ void CatalogManagerView::updateDir(TQString relDir)
deleteDirItem(relDir);
// if this directory has to be removed, check, if
// the tqparent directory has to be removed too
const int index=relDir.findRev("/",relDir.length()-2);
if(index<0)
{
@@ -2266,7 +2266,7 @@ void CatalogManagerView::directoryChanged(const TQString& dir)
CatManListItem* thisItem=_dirList[relDir];
if(!thisItem)
{
- // if this item is not in the list search for next existing tqparent item
+ // if this item is not in the list search for next existing parent item
TQString prevRelDir;
do
{
@@ -2289,7 +2289,7 @@ void CatalogManagerView::directoryChanged(const TQString& dir)
}
else
{
- // if a tqparent item dir is found, create the needed item in this dir
+ // if a parent item dir is found, create the needed item in this dir
// and build the tree from this item on
kdDebug(KBABEL_CATMAN) << "building dir: " << prevRelDir << endl;
CatManListItem* item = new CatManListItem(this, thisItem,_settings.poBaseDir+prevRelDir
@@ -2624,7 +2624,7 @@ CatManListItem *CatalogManagerView::itemBelow( CatManListItem *item )
{
while( !static_cast<CatManListItem *>( item->nextSibling() ) )
{
- item = static_cast<CatManListItem *>( item->tqparent() );
+ item = static_cast<CatManListItem *>( item->parent() );
if( !item ) return item;
}
return static_cast<CatManListItem *>( item->nextSibling() );
@@ -2634,7 +2634,7 @@ CatManListItem *CatalogManagerView::itemBelow( CatManListItem *item )
{
while( !static_cast<CatManListItem *>( item->nextSibling() ) )
{
- item = static_cast<CatManListItem *>( item->tqparent());
+ item = static_cast<CatManListItem *>( item->parent());
if( !item ) return item;
}
return static_cast<CatManListItem *>( item->nextSibling() );
@@ -2651,7 +2651,7 @@ CatManListItem *CatalogManagerView::itemAbove( CatManListItem *item )
{
while( !static_cast<CatManListItem *>( item->previousSibling() ) )
{
- item = static_cast<CatManListItem *>( item->tqparent() );
+ item = static_cast<CatManListItem *>( item->parent() );
if( !item ) return item;
}
return static_cast<CatManListItem *>( item->previousSibling() );
@@ -2661,7 +2661,7 @@ CatManListItem *CatalogManagerView::itemAbove( CatManListItem *item )
{
while( !static_cast<CatManListItem *>( item->previousSibling() ) )
{
- item = static_cast<CatManListItem *>( item->tqparent());
+ item = static_cast<CatManListItem *>( item->parent());
if( !item ) return item;
}
return static_cast<CatManListItem *>( item->previousSibling() );
@@ -2206,7 +2206,7 @@ void CatalogManagerView::updateDir(TQString relDir)
deleteDirItem(relDir);
// if this directory has to be removed, check, if
- // the tqparent directory has to be removed too
+ // the parent directory has to be removed too
const int index=relDir.findRev("/",relDir.length()-2);
if(index<0)